# Python package for STANAG 4586 Edition A Version 1
## Tested with python 3.8+

This repository conotains code that will enable encoding/decoding of STANAG messages.
So far the following messages have been implemented which should enable basic communication with a platform, messages are being continually added, please check back soon for updates.
- Message wrapper
- 01
- 20
- 21
- 300
- 301
- 302
- 1200
